export { hexToRgba } from 'src/utils';
import { BoxProps as BoxProps$1 } from '@mui/material/Box';
import * as React from 'react';
import React__default, { ReactNode, ForwardRefExoticComponent, RefAttributes, ComponentType } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { BreadcrumbsProps as BreadcrumbsProps$1 } from '@mui/material/Breadcrumbs';
import { ButtonProps as ButtonProps$1 } from '@mui/material/Button';
import { PaletteColors as PaletteColors$1, StreamlineIcons as StreamlineIcons$1 } from 'src/typings';
import * as _mui_material from '@mui/material';
import { SxProps, Theme, PaletteOptions } from '@mui/material';
export * from '@mui/material';
import { BoxProps as BoxProps$2 } from 'src/components';
import * as styled_components from 'styled-components';
import * as _mui_material_OverridableComponent from '@mui/material/OverridableComponent';
import * as _mui_system from '@mui/system';
import { SxProps as SxProps$1 } from '@mui/system';
import * as _mui_material_styles from '@mui/material/styles';
export { StyledEngineProvider, ThemeProvider, styled, useTheme } from '@mui/material/styles';
import { TypographyProps as TypographyProps$1 } from '@mui/material/Typography';
import * as react from '@phosphor-icons/react';
export { react as Icon };

type BoxProps = BoxProps$1;
declare const Box: React__default.ForwardRefExoticComponent<Omit<BoxProps, "ref"> & React__default.RefAttributes<unknown>>;

type BreadcrumbsProps = BreadcrumbsProps$1;
declare const Breadcrumbs: ({ children, ...props }: BreadcrumbsProps) => react_jsx_runtime.JSX.Element;

type Variant = 'primary' | 'secondary' | 'tertiary' | 'text' | 'link' | 'nav';
type OmitMuiButtonWrapperProps = Omit<ButtonProps$1, 'color' | 'variant'>;
interface ButtonWrapperProps extends OmitMuiButtonWrapperProps {
    variant?: Variant;
    color?: PaletteColors$1;
}
interface ButtonProps extends ButtonProps$1 {
    customVariant?: Variant;
    customColor?: PaletteColors$1;
}
declare const Button: React__default.ForwardRefExoticComponent<Omit<ButtonWrapperProps, "ref"> & React__default.RefAttributes<HTMLButtonElement>>;

type ArrowPosition = 'top' | 'bottom' | 'left' | 'right';
type xPosition = 'left' | 'right' | 'center';
type yPosition = 'top' | 'bottom' | 'center';
interface ShowTooltipArgs<T> {
    tooltipData: T;
    tooltipLeft?: number;
    tooltipTop?: number;
}
interface TooltipParams<T> {
    tooltipOpen: boolean;
    tooltipLeft?: number;
    tooltipTop?: number;
    tooltipData?: T;
    showTooltip: (args: ShowTooltipArgs<T>) => void;
    hideTooltip: () => void;
    arrowPosition?: ArrowPosition | undefined;
    xPosition?: xPosition;
    yPosition?: yPosition;
    unitMeasurement?: string;
}
type GraphTooltipData = {
    label?: string;
    value?: string | number;
}[];
interface GraphTooltipProps {
    rows: {
        label?: string;
        value?: string | number;
    }[];
    unitMeasurement?: string;
    top?: number;
    left?: number;
    right?: number;
    width?: number | 'auto';
    height?: number | 'auto';
    className?: string;
    sx?: SxProps<Theme>;
    arrowPosition?: ArrowPosition;
    xPosition?: xPosition;
    yPosition?: yPosition;
    open?: boolean;
}
declare const GraphTooltip: ({ className, sx, rows, unitMeasurement, top, left, right, width, height, arrowPosition, xPosition, yPosition, open, }: GraphTooltipProps) => react_jsx_runtime.JSX.Element | null;

interface PageProps extends BoxProps$2 {
    withHeader?: boolean;
}
declare const Page: React.ForwardRefExoticComponent<Omit<PageProps, "ref"> & React.RefAttributes<HTMLDivElement>>;

type RowProps = BoxProps$2;
declare const Row: styled_components.StyledComponent<React.ForwardRefExoticComponent<Omit<BoxProps$2, "ref"> & React.RefAttributes<unknown>>, _mui_material_styles.Theme, _mui_system.MUIStyledCommonProps<_mui_material_styles.Theme> & _mui_system.BoxOwnProps<_mui_material_styles.Theme> & _mui_material_OverridableComponent.CommonProps & Omit<Omit<React.DetailedHTMLProps<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, "ref"> & {
    ref?: ((instance: HTMLDivElement | null) => void | React.DO_NOT_USE_OR_YOU_WILL_BE_FIRED_CALLBACK_REF_RETURN_VALUES[keyof React.DO_NOT_USE_OR_YOU_WILL_BE_FIRED_CALLBACK_REF_RETURN_VALUES]) | React.RefObject<HTMLDivElement> | null | undefined;
}, keyof _mui_material_OverridableComponent.CommonProps | keyof _mui_system.BoxOwnProps<_mui_material_styles.Theme>>, never>;

type StreamlineIconProps = {
    name: StreamlineIcons$1;
};
declare const StreamlineIcon: ({ name }: StreamlineIconProps) => react_jsx_runtime.JSX.Element;

type FontWeightVariant = 'regular' | 'medium' | 'semiBold' | 'bold';
interface TypographyProps extends TypographyProps$1 {
    /**
     * @default 'regular'
     */
    weight?: FontWeightVariant;
}
declare const Typography: React.ForwardRefExoticComponent<Omit<TypographyProps, "ref"> & React.RefAttributes<HTMLElement>>;

type BaseCardProps = {
    children?: ReactNode;
};
type CardHeaderProps = {
    title?: string;
    description?: string;
    actions?: ReactNode;
    sx?: SxProps$1;
    children?: ReactNode;
};
type CardBodyProps = {
    children: ReactNode;
    sx?: SxProps$1;
};
type BaseCardComponent = ForwardRefExoticComponent<BaseCardProps & RefAttributes<HTMLDivElement>> & {
    Header: ComponentType<CardHeaderProps>;
    Body: ComponentType<CardBodyProps>;
};
declare const BaseCard: BaseCardComponent;

declare const ui: {
    blue: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    green: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    yellow: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    red: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    gray: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    coolGray: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    white: {
        500: string;
    };
    black: {
        500: string;
    };
};

declare const collage: {
    raspberry: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    teal: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    citron: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
};

declare const audience: {
    multiculturalYellow: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    generationsOrange: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    lgtbqPurple: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    genderTeal: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    parentsAndKidsGreen: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
    kidsGreen: {
        50: string;
        100: string;
        200: string;
        300: string;
        400: string;
        500: string;
        600: string;
        700: string;
        800: string;
        900: string;
    };
};

declare const themeColors: {
    primary: {
        main: string;
        dark: string;
        light: string;
    };
    secondary: {
        main: string;
        dark: string;
        light: string;
    };
    error: {
        main: string;
        light: string;
        dark: string;
    };
    warning: {
        main: string;
        light: string;
        dark: string;
    };
    success: {
        main: string;
        light: string;
        dark: string;
    };
    text: {
        primary: string;
        secondary: string;
        disabled: string;
    };
};

declare enum PaletteColors {
    collageRaspberry = "collageRaspberry",
    collageTeal = "collageTeal",
    collageCitron = "collageCitron",
    audienceMulticulturalYellow = "audienceMulticulturalYellow",
    audienceGenerationsOrange = "audienceGenerationsOrange",
    audienceLgtbqPurple = "audienceLgtbqPurple",
    audienceGenderTeal = "audienceGenderTeal",
    audienceParentsAndKidsGreen = "audienceParentsAndKidsGreen",
    audienceKidsGreen = "audienceKidsGreen",
    uiBlue = "uiBlue",
    uiGreen = "uiGreen",
    uiYellow = "uiYellow",
    uiRed = "uiRed",
    uiGray = "uiGray",
    uiCoolGray = "uiCoolGray",
    uiWhite = "uiWhite"
}
declare enum StreamlineIcons {
    Lightbulb = "lightbulb",
    PerformanceIncrease = "performance_increase",
    Like = "like",
    ShoppingBasket = "shopping_basket"
}

declare module '@mui/material/styles' {
    interface DefaultColors {
        black: string;
        white: string;
    }
    interface CustomColorShades {
        '50'?: string;
        '100'?: string;
        '200'?: string;
        '300'?: string;
        '400'?: string;
        '500'?: string;
        '600'?: string;
        '700'?: string;
        '800'?: string;
        '900'?: string;
    }
    interface CustomPalette {
        collageRaspberry: CustomColorShades;
        collageTeal: CustomColorShades;
        collageCitron: CustomColorShades;
        audienceMulticulturalYellow: CustomColorShades;
        audienceGenerationsOrange: CustomColorShades;
        audienceLgtbqPurple: CustomColorShades;
        audienceGenderTeal: CustomColorShades;
        audienceParentsAndKidsGreen: CustomColorShades;
        audienceKidsGreen: CustomColorShades;
        uiBlue: CustomColorShades;
        uiGreen: CustomColorShades;
        uiYellow: CustomColorShades;
        uiRed: CustomColorShades;
        uiGray: CustomColorShades;
        uiCoolGray: CustomColorShades;
        uiWhite: CustomColorShades;
        defaultColors: DefaultColors;
    }
    interface CustomPaletteOptions {
        collageRaspberry?: CustomColorShades;
        collageTeal?: CustomColorShades;
        collageCitron?: CustomColorShades;
        audienceMulticulturalYellow?: CustomColorShades;
        audienceGenerationsOrange?: CustomColorShades;
        audienceLgtbqPurple?: CustomColorShades;
        audienceGenderTeal?: CustomColorShades;
        audienceParentsAndKidsGreen?: CustomColorShades;
        audienceKidsGreen?: CustomColorShades;
        uiBlue?: CustomColorShades;
        uiGreen?: CustomColorShades;
        uiYellow?: CustomColorShades;
        uiRed?: CustomColorShades;
        uiGray?: CustomColorShades;
        uiCoolGray?: CustomColorShades;
        uiWhite?: CustomColorShades;
        defaultColors?: DefaultColors;
    }
    interface CustomColors {
        collageRaspberry?: CustomColorShades;
        collageTeal?: CustomColorShades;
        collageCitron?: CustomColorShades;
        audienceMulticulturalYellow?: CustomColorShades;
        audienceGenerationsOrange?: CustomColorShades;
        audienceLgtbqPurple?: CustomColorShades;
        audienceGenderTeal?: CustomColorShades;
        audienceParentsAndKidsGreen?: CustomColorShades;
        audienceKidsGreen?: CustomColorShades;
        uiBlue?: CustomColorShades;
        uiGreen?: CustomColorShades;
        uiYellow?: CustomColorShades;
        uiRed?: CustomColorShades;
        uiGray?: CustomColorShades;
        uiCoolGray?: CustomColorShades;
        uiWhite?: CustomColorShades;
    }
    interface PaletteOptions extends CustomPaletteOptions {
    }
    interface Palette extends CustomPalette {
    }
    interface TypographyVariants {
        b1: React__default.CSSProperties;
        b2: React__default.CSSProperties;
        b3: React__default.CSSProperties;
        caption: React__default.CSSProperties;
    }
    interface TypographyVariantsOptions {
        b1?: React__default.CSSProperties;
        b2?: React__default.CSSProperties;
        b3?: React__default.CSSProperties;
        caption?: React__default.CSSProperties;
    }
    interface ButtonVariants {
        primary: string;
        secondary: string;
        tertiary: string;
        link: string;
        nav: string;
        text: string;
    }
    interface ButtonPropsVariantOverrides {
        primary: string;
        secondary: string;
        tertiary: string;
        link: string;
        nav: string;
        text: string;
    }
}
declare module '@mui/material/Typography/Typography' {
    interface TypographyPropsVariantOverrides {
        b1: true;
        b2: true;
        b3: true;
        caption: true;
        h4: false;
        h5: false;
        h6: false;
        subtitle1: false;
        subtitle2: false;
        body1: false;
        body2: false;
        button: false;
        overline: false;
        poster: false;
    }
}
declare module '@mui/material/Button/Button' {
    interface ButtonPropsVariantOverrides {
        primary: true;
        secondary: true;
        filled: false;
        contained: false;
        text: true;
    }
    interface ButtonPropsColorOverrides {
        basic: false;
        info: false;
        success: false;
        secondary: false;
        inherit: false;
    }
}

declare const palette: PaletteOptions;
declare const theme: _mui_material.Theme;

export { BaseCard, BaseCardProps, Box, BoxProps, Breadcrumbs, BreadcrumbsProps, Button, ButtonProps, GraphTooltip, GraphTooltipData, Page, PageProps, PaletteColors, Row, RowProps, ShowTooltipArgs, StreamlineIcon, StreamlineIconProps, StreamlineIcons, TooltipParams, Typography, TypographyProps, audience, collage, palette, theme, themeColors, ui };
